==> haskell-unix-compat-0.4.3.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unix-compat.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unix-compat
version: 0.4.3.1
id: unix-compat-0.4.3.1-Ausmw6d7KIwA7sl52mzqxC
key: unix-compat-0.4.3.1-Ausmw6d7KIwA7sl52mzqxC
license: BSD3
maintainer: Jacob Stanley <jacob@stanley.io>
homepage: http://github.com/jystic/unix-compat
synopsis: Portable POSIX-compatibility layer.
description:
    This package provides portable implementations of parts
    of the unix package. This package re-exports the unix
    package when available. When it isn'\''t available,
    portable implementations are used.
category: System
author: Björn Bringert, Duncan Coutts, Jacob Stanley, Bryan O'\''Sullivan
exposed: True
exposed-modules:
    System.PosixCompat System.PosixCompat.Extensions
    System.PosixCompat.Files System.PosixCompat.Temp
    System.PosixCompat.Time System.PosixCompat.Types
    System.PosixCompat.Unistd System.PosixCompat.User
abi: 8ee775b41a9d3b0385e9cc753fb2ffe7
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/unix-compat-0.4.3.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/unix-compat-0.4.3.1
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/unix-compat-0.4.3.1
hs-libraries: HSunix-compat-0.4.3.1-Ausmw6d7KIwA7sl52mzqxC
include-dirs: /usr/lib/ghc-8.0.2/site-local/unix-compat-0.4.3.1/include
includes:
    HsUnixCompat.h
depends:
    base-4.9.1.0 unix-2.7.2.1
haddock-interfaces: /usr/share/doc/haskell-unix-compat/html/unix-compat.haddock
haddock-html: /usr/share/doc/haskell-unix-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unix-compat-0.4.3.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unix-compat.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unix-compat
version: 0.4.3.1
id: unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp
key: unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp
license: BSD3
maintainer: Jacob Stanley <jacob@stanley.io>
homepage: http://github.com/jystic/unix-compat
synopsis: Portable POSIX-compatibility layer.
description:
    This package provides portable implementations of parts
    of the unix package. This package re-exports the unix
    package when available. When it isn'\''t available,
    portable implementations are used.
category: System
author: Björn Bringert, Duncan Coutts, Jacob Stanley, Bryan O'\''Sullivan
exposed: True
indefinite: False
exposed-modules:
    System.PosixCompat System.PosixCompat.Extensions
    System.PosixCompat.Files System.PosixCompat.Temp
    System.PosixCompat.Time System.PosixCompat.Types
    System.PosixCompat.Unistd System.PosixCompat.User
abi: f0e3615d16ccc9a099618a4b1bfc9d59
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/unix-compat-0.4.3.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/unix-compat-0.4.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/unix-compat-0.4.3.1
hs-libraries: HSunix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp
include-dirs: /usr/lib/ghc-8.2.1/site-local/unix-compat-0.4.3.1/include
includes:
    HsUnixCompat.h
depends:
    base-4.10.0.0 unix-2.7.2.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             unix-2.7.2.2=7af8630098b53e228272ffaea5bacf62
haddock-interfaces: /usr/share/doc/haskell-unix-compat/html/unix-compat.haddock
haddock-html: /usr/share/doc/haskell-unix-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
